The Tauri API interface.
Re-exports
pub use clap;
Modules
- cli
cliTypes and functions related to CLI arguments. - dialog
desktopanddialogUse native message and file open/save dialogs. - Types and functions related to file system directory management.
- Types and functions related to file operations.
- http
http-apiTypes and functions related to HTTP request. - Types and functions related to Inter Procedure Call(IPC).
- notification
desktopandnotificationTypes and functions related to desktop notifications. - os
os-apiTypes and functions related to operating system operations. - Types and functions related to file system path operations.
- Types and functions related to child processes management.
- shell
shell-open-apiTypes and functions related to shell. - Compare two semantic versions.
Enums
- The error type of Tauri API module. The error types.
Type Aliases
- The result type of Tauri API module.