Module image

Module image 

Image types used by this crate and also referenced by the JavaScript API layer.

Structs

Image
An RGBA Image in row-major order from top to bottom.

Enums

JsImage
An image type that accepts file paths, raw bytes, previously loaded images and image objects.