CapabilityBuilder

Struct CapabilityBuilder 

pub struct CapabilityBuilder(/* private fields */);
Available on crate feature dynamic-acl only.
A builder for a Capability.

Implementations

Source

impl CapabilityBuilder

pub fn new(identifier: impl Into<String>) -> Self

Creates a new capability builder with a unique identifier.

pub fn remote(self, url: String) -> Self

Allows this capability to be used by a remote URL.

pub fn local(self, local: bool) -> Self

Whether this capability is applied on local app URLs or not. Defaults to true.

pub fn window(self, window: impl Into<String>) -> Self

Link this capability to the given window label.

pub fn windows( self, windows: impl IntoIterator<Item = impl Into<String>>, ) -> Self

Link this capability to the a list of window labels.

pub fn webview(self, webview: impl Into<String>) -> Self

Link this capability to the given webview label.

pub fn webviews( self, webviews: impl IntoIterator<Item = impl Into<String>>, ) -> Self

Link this capability to the a list of window labels.

pub fn permission(self, permission: impl Into<String>) -> Self

Add a new permission to this capability.

pub fn permission_scoped<T: Serialize>( self, permission: impl Into<String>, allowed: Vec<T>, denied: Vec<T>, ) -> Self

Add a new scoped permission to this capability.

pub fn platform(self, platform: Target) -> Self

Adds a target platform for this capability.

By default all platforms are applied.

pub fn platforms(self, platforms: impl IntoIterator<Item = Target>) -> Self

Adds target platforms for this capability.

By default all platforms are applied.