CommandScope

Struct CommandScope 

pub struct CommandScope<T: ScopeObject> { /* private fields */ }
Access scope for a command that can be retrieved directly in the command function.

Implementations

Source

impl<T: ScopeObject> CommandScope<T>

pub fn allows(&self) -> &Vec<Arc<T>>

What this access scope allows.

pub fn denies(&self) -> &Vec<Arc<T>>

What this access scope denies.

Source

impl<T: ScopeObjectMatch> CommandScope<T>

pub fn matches(&self, input: &T::Input) -> bool

Ensure all deny scopes were not matched and any allow scopes were.

This WILL return true if the allow scopes are empty and the deny scopes did not trigger. If you require at least one allow scope, then ensure the allow scopes are not empty before calling this method.

if scope.allows().is_empty() {
  return Err("you need to specify at least 1 allow scope!");
}
Example
#[derive(Debug, Clone, Serialize, Deserialize)]
#[command]
fn my_command(scope: CommandScope<Scope>, input: String) -> Result<String, &'static str> {
  if scope.matches(&input) {
    do_work(input)
  } else {
    Err("Scope didn't match input")
  }
}