JavaScriptChannelId

Struct JavaScriptChannelId 

pub struct JavaScriptChannelId(/* private fields */);
The ID of a channel that was defined on the JavaScript layer.

Useful when expecting Channel as part of a JSON object instead of a top-level command argument.

Examples

use tauri::{ipc::JavaScriptChannelId, Runtime, Webview};

#[derive(serde::Deserialize)]
#[serde(rename_all = "camelCase")]
struct Button {
  label: String,
  on_click: JavaScriptChannelId,
}

#[tauri::command]
fn add_button<R: Runtime>(webview: Webview<R>, button: Button) {
  let channel = button.on_click.channel_on(webview);
  channel.send("clicked").unwrap();
}

Implementations

Source

impl JavaScriptChannelId

pub fn channel_on<R: Runtime, TSend>( &self, webview: Webview<R>, ) -> Channel<TSend>

Gets a Channel for this channel ID on the given Webview.