MenuItemKind

Enum MenuItemKind 

pub enum MenuItemKind<R: Runtime> {
    MenuItem(MenuItem<R>),
    Submenu(Submenu<R>),
    Predefined(PredefinedMenuItem<R>),
    Check(CheckMenuItem<R>),
    Icon(IconMenuItem<R>),
}
Available on desktop only.
An enumeration of all menu item kinds that could be added to a Menu or Submenu

Variants



MenuItem(MenuItem<R>)

Normal menu item



Submenu(Submenu<R>)

Submenu menu item



Predefined(PredefinedMenuItem<R>)

Predefined menu item



Check(CheckMenuItem<R>)

Check menu item



Icon(IconMenuItem<R>)

Icon menu item

Implementations

Source

impl<R: Runtime> MenuItemKind<R>

pub fn id(&self) -> &MenuId

Returns a unique identifier associated with this menu item.

pub fn as_menuitem(&self) -> Option<&MenuItem<R>>

Casts this item to a MenuItem, and returns None if it wasn’t.

pub fn as_menuitem_unchecked(&self) -> &MenuItem<R>

Casts this item to a MenuItem, and panics if it wasn’t.

pub fn as_submenu(&self) -> Option<&Submenu<R>>

Casts this item to a Submenu, and returns None if it wasn’t.

pub fn as_submenu_unchecked(&self) -> &Submenu<R>

Casts this item to a Submenu, and panics if it wasn’t.

pub fn as_predefined_menuitem(&self) -> Option<&PredefinedMenuItem<R>>

Casts this item to a PredefinedMenuItem, and returns None if it wasn’t.

pub fn as_predefined_menuitem_unchecked(&self) -> &PredefinedMenuItem<R>

Casts this item to a PredefinedMenuItem, and panics if it wasn’t.

pub fn as_check_menuitem(&self) -> Option<&CheckMenuItem<R>>

Casts this item to a CheckMenuItem, and returns None if it wasn’t.

pub fn as_check_menuitem_unchecked(&self) -> &CheckMenuItem<R>

Casts this item to a CheckMenuItem, and panics if it wasn’t.

pub fn as_icon_menuitem(&self) -> Option<&IconMenuItem<R>>

Casts this item to a IconMenuItem, and returns None if it wasn’t.

pub fn as_icon_menuitem_unchecked(&self) -> &IconMenuItem<R>

Casts this item to a IconMenuItem, and panics if it wasn’t.