PredefinedMenuItem

Struct PredefinedMenuItem 

pub struct PredefinedMenuItem<R: Runtime>(/* private fields */);
Available on desktop only.
A predefined (native) menu item which has a predefined behavior by the OS or by this crate.

Implementations

Source

impl<R: Runtime> PredefinedMenuItem<R>

pub fn separator<M: Manager<R>>(manager: &M) -> Result<Self>

Separator menu item

pub fn copy<M: Manager<R>>(manager: &M, text: Option<&str>) -> Result<Self>

Copy menu item

pub fn cut<M: Manager<R>>(manager: &M, text: Option<&str>) -> Result<Self>

Cut menu item

pub fn paste<M: Manager<R>>(manager: &M, text: Option<&str>) -> Result<Self>

Paste menu item

pub fn select_all<M: Manager<R>>( manager: &M, text: Option<&str>, ) -> Result<Self>

SelectAll menu item

pub fn undo<M: Manager<R>>(manager: &M, text: Option<&str>) -> Result<Self>

Undo menu item

Platform-specific:
  • Windows / Linux: Unsupported.
pub fn redo<M: Manager<R>>(manager: &M, text: Option<&str>) -> Result<Self>

Redo menu item

Platform-specific:
  • Windows / Linux: Unsupported.
pub fn minimize<M: Manager<R>>(manager: &M, text: Option<&str>) -> Result<Self>

Minimize window menu item

Platform-specific:
  • Linux: Unsupported.
pub fn maximize<M: Manager<R>>(manager: &M, text: Option<&str>) -> Result<Self>

Maximize window menu item

Platform-specific:
  • Linux: Unsupported.
pub fn fullscreen<M: Manager<R>>( manager: &M, text: Option<&str>, ) -> Result<Self>

Fullscreen menu item

Platform-specific:
  • Windows / Linux: Unsupported.
pub fn hide<M: Manager<R>>(manager: &M, text: Option<&str>) -> Result<Self>

Hide window menu item

Platform-specific:
  • Linux: Unsupported.
pub fn hide_others<M: Manager<R>>( manager: &M, text: Option<&str>, ) -> Result<Self>

Hide other windows menu item

Platform-specific:
  • Linux: Unsupported.
pub fn show_all<M: Manager<R>>(manager: &M, text: Option<&str>) -> Result<Self>

Show all app windows menu item

Platform-specific:
  • Windows / Linux: Unsupported.
pub fn close_window<M: Manager<R>>( manager: &M, text: Option<&str>, ) -> Result<Self>

Close window menu item

Platform-specific:
  • Linux: Unsupported.
pub fn quit<M: Manager<R>>(manager: &M, text: Option<&str>) -> Result<Self>

Quit app menu item

Platform-specific:
  • Linux: Unsupported.
pub fn about<M: Manager<R>>( manager: &M, text: Option<&str>, metadata: Option<AboutMetadata<'_>>, ) -> Result<Self>

About app menu item

pub fn services<M: Manager<R>>(manager: &M, text: Option<&str>) -> Result<Self>

Services menu item

Platform-specific:
  • Windows / Linux: Unsupported.
pub fn bring_all_to_front<M: Manager<R>>( manager: &M, text: Option<&str>, ) -> Result<Self>

Bring All to Front menu item

Platform-specific:
  • Windows / Linux: Unsupported.
pub fn id(&self) -> &MenuId

Returns a unique identifier associated with this menu item.

pub fn text(&self) -> Result<String>

Get the text for this menu item.

pub fn set_text<S: AsRef<str>>(&self, text: S) -> Result<()>

Set the text for this menu item. text could optionally contain an & before a character to assign this character as the mnemonic for this menu item. To display a & without assigning a mnemenonic, use &&.

pub fn app_handle(&self) -> &AppHandle<R>

The application handle associated with this type.