pub enum NewWindowResponse<R: Runtime> {
Allow,
Create {
window: WebviewWindow<R>,
},
Deny,
}Expand description
Response for the new window request handler.
Variants
Allow
Allow the window to be opened with the default implementation.
Create
Allow the window to be opened, with the given window.
Platform-specific:
Linux: The webview must be related to the caller webview. See WebviewBuilder::with_related_view.
Windows: The webview must use the same environment as the caller webview. See [WebviewBuilder::with_environment].
macOS: The webview must use the same webview configuration as the caller webview. See [WebviewBuilder::with_webview_configuration] and [NewWindowFeatures::webview_configuration].
Fields

window: WebviewWindow<R>Window that was created.
Deny
Deny the window from being opened.