pub struct CapabilityBuilder(/* private fields */);Available on crate feature
dynamic-acl only.Expand description
A builder for a Capability.
Implementations
Sourceimpl CapabilityBuilder
impl CapabilityBuilder
Sourcepub fn new(identifier: impl Into<String>) -> Self
pub fn new(identifier: impl Into<String>) -> Self
Creates a new capability builder with a unique identifier.
Sourcepub fn local(self, local: bool) -> Self
pub fn local(self, local: bool) -> Self
Whether this capability is applied on local app URLs or not. Defaults to true.
Sourcepub fn window(self, window: impl Into<String>) -> Self
pub fn window(self, window: impl Into<String>) -> Self
Link this capability to the given window label.
Sourcepub fn windows(
self,
windows: impl IntoIterator<Item = impl Into<String>>,
) -> Self
pub fn windows( self, windows: impl IntoIterator<Item = impl Into<String>>, ) -> Self
Link this capability to the a list of window labels.
Sourcepub fn webview(self, webview: impl Into<String>) -> Self
pub fn webview(self, webview: impl Into<String>) -> Self
Link this capability to the given webview label.
Sourcepub fn webviews(
self,
webviews: impl IntoIterator<Item = impl Into<String>>,
) -> Self
pub fn webviews( self, webviews: impl IntoIterator<Item = impl Into<String>>, ) -> Self
Link this capability to the a list of window labels.
Sourcepub fn permission(self, permission: impl Into<String>) -> Self
pub fn permission(self, permission: impl Into<String>) -> Self
Add a new permission to this capability.
Sourcepub fn permission_scoped<T: Serialize>(
self,
permission: impl Into<String>,
allowed: Vec<T>,
denied: Vec<T>,
) -> Self
pub fn permission_scoped<T: Serialize>( self, permission: impl Into<String>, allowed: Vec<T>, denied: Vec<T>, ) -> Self
Add a new scoped permission to this capability.
Sourcepub fn platform(self, platform: Target) -> Self
pub fn platform(self, platform: Target) -> Self
Adds a target platform for this capability.
By default all platforms are applied.
Sourcepub fn platforms(self, platforms: impl IntoIterator<Item = Target>) -> Self
pub fn platforms(self, platforms: impl IntoIterator<Item = Target>) -> Self
Adds target platforms for this capability.
By default all platforms are applied.