pub struct PredefinedMenuItem<R: Runtime>(/* private fields */);Available on
desktop only.Expand description
A predefined (native) menu item which has a predefined behavior by the OS or by this crate.
Implementations
Sourceimpl<R: Runtime> PredefinedMenuItem<R>
impl<R: Runtime> PredefinedMenuItem<R>
Sourcepub fn select_all<M: Manager<R>>(
manager: &M,
text: Option<&str>,
) -> Result<Self>
pub fn select_all<M: Manager<R>>( manager: &M, text: Option<&str>, ) -> Result<Self>
SelectAll menu item
Sourcepub fn about<M: Manager<R>>(
manager: &M,
text: Option<&str>,
metadata: Option<AboutMetadata<'_>>,
) -> Result<Self>
pub fn about<M: Manager<R>>( manager: &M, text: Option<&str>, metadata: Option<AboutMetadata<'_>>, ) -> Result<Self>
About app menu item
Sourcepub fn set_text<S: AsRef<str>>(&self, text: S) -> Result<()>
pub fn set_text<S: AsRef<str>>(&self, text: S) -> Result<()>
Set the text for this menu item. text could optionally contain
an & before a character to assign this character as the mnemonic
for this menu item. To display a & without assigning a mnemenonic, use &&.
Sourcepub fn app_handle(&self) -> &AppHandle<R>
pub fn app_handle(&self) -> &AppHandle<R>
The application handle associated with this type.