pub struct Window<R: Runtime = Wry> { /* private fields */ }wry only.Expand description
A window managed by Tauri.
This type also implements Manager which allows you to manage other windows attached to
the same application.
Implementations
Sourceimpl<R: Runtime> Window<R>
Base window functions.
impl<R: Runtime> Window<R>
Base window functions.
Sourcepub fn builder<M: Manager<R>, L: Into<String>>(
manager: &M,
label: L,
) -> WindowBuilder<'_, R, M>
Available on crate feature unstable only.
pub fn builder<M: Manager<R>, L: Into<String>>( manager: &M, label: L, ) -> WindowBuilder<'_, R, M>
unstable only.Initializes a window builder with the given window label.
Data URLs are only supported with the webview-data-url feature flag.
Sourcepub fn run_on_main_thread<F: FnOnce() + Send + 'static>(
&self,
f: F,
) -> Result<()>
pub fn run_on_main_thread<F: FnOnce() + Send + 'static>( &self, f: F, ) -> Result<()>
Runs the given closure on the main thread.
Sourcepub fn on_window_event<F: Fn(&WindowEvent) + Send + 'static>(&self, f: F)
pub fn on_window_event<F: Fn(&WindowEvent) + Send + 'static>(&self, f: F)
Registers a window event listener.
Sourceimpl<R: Runtime> Window<R>
Window getters.
impl<R: Runtime> Window<R>
Window getters.
Sourcepub fn scale_factor(&self) -> Result<f64>
pub fn scale_factor(&self) -> Result<f64>
Returns the scale factor that can be used to map logical pixels to physical pixels, and vice versa.
Sourcepub fn inner_position(&self) -> Result<PhysicalPosition<i32>>
pub fn inner_position(&self) -> Result<PhysicalPosition<i32>>
Returns the position of the top-left hand corner of the window’s client area relative to the top-left hand corner of the desktop.
Sourcepub fn outer_position(&self) -> Result<PhysicalPosition<i32>>
pub fn outer_position(&self) -> Result<PhysicalPosition<i32>>
Returns the position of the top-left hand corner of the window relative to the top-left hand corner of the desktop.
Sourcepub fn inner_size(&self) -> Result<PhysicalSize<u32>>
pub fn inner_size(&self) -> Result<PhysicalSize<u32>>
Returns the physical size of the window’s client area.
The client area is the content of the window, excluding the title bar and borders.
Sourcepub fn outer_size(&self) -> Result<PhysicalSize<u32>>
pub fn outer_size(&self) -> Result<PhysicalSize<u32>>
Returns the physical size of the entire window.
These dimensions include the title bar and borders. If you don’t want that (and you usually don’t), use inner_size instead.
Sourcepub fn is_fullscreen(&self) -> Result<bool>
pub fn is_fullscreen(&self) -> Result<bool>
Gets the window’s current fullscreen state.
Sourcepub fn is_minimized(&self) -> Result<bool>
pub fn is_minimized(&self) -> Result<bool>
Gets the window’s current minimized state.
Sourcepub fn is_maximized(&self) -> Result<bool>
pub fn is_maximized(&self) -> Result<bool>
Gets the window’s current maximized state.
Sourcepub fn is_focused(&self) -> Result<bool>
pub fn is_focused(&self) -> Result<bool>
Gets the window’s current focus state.
Sourcepub fn is_decorated(&self) -> Result<bool>
pub fn is_decorated(&self) -> Result<bool>
Gets the window’s current decoration state.
Sourcepub fn is_resizable(&self) -> Result<bool>
pub fn is_resizable(&self) -> Result<bool>
Gets the window’s current resizable state.
Sourcepub fn is_enabled(&self) -> Result<bool>
pub fn is_enabled(&self) -> Result<bool>
Whether the window is enabled or disabled.
Sourcepub fn is_always_on_top(&self) -> Result<bool>
pub fn is_always_on_top(&self) -> Result<bool>
Determines if this window should always be on top of other windows.
Platform-specific
- iOS / Android: Unsupported.
Sourcepub fn is_maximizable(&self) -> Result<bool>
pub fn is_maximizable(&self) -> Result<bool>
Gets the window’s native maximize button state
Platform-specific
- Linux / iOS / Android: Unsupported.
Sourcepub fn is_minimizable(&self) -> Result<bool>
pub fn is_minimizable(&self) -> Result<bool>
Gets the window’s native minimize button state
Platform-specific
- Linux / iOS / Android: Unsupported.
Sourcepub fn is_closable(&self) -> Result<bool>
pub fn is_closable(&self) -> Result<bool>
Sourcepub fn is_visible(&self) -> Result<bool>
pub fn is_visible(&self) -> Result<bool>
Gets the window’s current visibility state.
Sourcepub fn current_monitor(&self) -> Result<Option<Monitor>>
pub fn current_monitor(&self) -> Result<Option<Monitor>>
Returns the monitor on which the window currently resides.
Returns None if current monitor can’t be detected.
Sourcepub fn monitor_from_point(&self, x: f64, y: f64) -> Result<Option<Monitor>>
pub fn monitor_from_point(&self, x: f64, y: f64) -> Result<Option<Monitor>>
Returns the monitor that contains the given point.
Sourcepub fn primary_monitor(&self) -> Result<Option<Monitor>>
pub fn primary_monitor(&self) -> Result<Option<Monitor>>
Returns the primary monitor of the system.
Returns None if it can’t identify any monitor as a primary one.
Sourcepub fn available_monitors(&self) -> Result<Vec<Monitor>>
pub fn available_monitors(&self) -> Result<Vec<Monitor>>
Returns the list of all the monitors available on the system.
Sourcepub fn activity_name(&self) -> Result<String>
Available on Android only.
pub fn activity_name(&self) -> Result<String>
Returns the name of the Android activity associated with this window.
Sourceimpl<R: Runtime> Window<R>
Window setters and actions.
impl<R: Runtime> Window<R>
Window setters and actions.
Sourcepub fn set_resizable(&self, resizable: bool) -> Result<()>
pub fn set_resizable(&self, resizable: bool) -> Result<()>
Determines if this window should be resizable. When resizable is set to false, native window’s maximize button is automatically disabled.
Sourcepub fn set_enabled(&self, enabled: bool) -> Result<()>
pub fn set_enabled(&self, enabled: bool) -> Result<()>
Enable or disable the window.
Sourcepub fn close(&self) -> Result<()>
pub fn close(&self) -> Result<()>
Closes this window. It emits crate::WindowEvent::CloseRequested first like a user-initiated close request so you can intercept it.
Sourcepub fn destroy(&self) -> Result<()>
pub fn destroy(&self) -> Result<()>
Destroys this window. Similar to Self::close but does not emit any events and force close the window instead.
Sourcepub fn set_background_color(&self, color: Option<Color>) -> Result<()>
pub fn set_background_color(&self, color: Option<Color>) -> Result<()>
Sets the window background color.
Platform-specific:
- Windows: alpha channel is ignored.
- iOS / Android: Unsupported.
Sourcepub fn set_content_protected(&self, protected: bool) -> Result<()>
pub fn set_content_protected(&self, protected: bool) -> Result<()>
Prevents the window contents from being captured by other apps.
Sourcepub fn set_min_size<S: Into<Size>>(&self, size: Option<S>) -> Result<()>
pub fn set_min_size<S: Into<Size>>(&self, size: Option<S>) -> Result<()>
Sets this window’s minimum inner size.
Sourcepub fn set_max_size<S: Into<Size>>(&self, size: Option<S>) -> Result<()>
pub fn set_max_size<S: Into<Size>>(&self, size: Option<S>) -> Result<()>
Sets this window’s maximum inner size.
Sourcepub fn set_size_constraints(
&self,
constraints: WindowSizeConstraints,
) -> Result<()>
pub fn set_size_constraints( &self, constraints: WindowSizeConstraints, ) -> Result<()>
Sets this window’s minimum inner width.
Sourcepub fn set_position<Pos: Into<Position>>(&self, position: Pos) -> Result<()>
pub fn set_position<Pos: Into<Position>>(&self, position: Pos) -> Result<()>
Sets this window’s position.
Sourcepub fn set_focusable(&self, focusable: bool) -> Result<()>
pub fn set_focusable(&self, focusable: bool) -> Result<()>
Sets whether the window can be focused.
Platform-specific
- macOS: If the window is already focused, it is not possible to unfocus it after calling
set_focusable(false). In this case, you might consider callingWindow::set_focusbut it will move the window to the back i.e. at the bottom in terms of z-order.